Commands

Enum Commands 

pub enum Commands {
    Build {
        root: String,
        out: String,
    },
    Refresh {
        root: String,
        out: String,
    },
    Find {
        query: String,
    },
    Context {
        path: String,
    },
    Impact {
        fqn: String,
    },
    Status,
    Fetch {
        path: String,
        symbol: String,
    },
    Blast {
        path: String,
        symbol: String,
    },
    Search {
        query: String,
    },
    Mcp,
}

Variants



Build

Build or refresh the project map index

Fields

root: String


Refresh

Alias for build

Fields

root: String


Find

Find a symbol across the codebase

Fields

query: String


Context

Get a dense architectural overview of a specific file

Fields

path: String


Impact

Analyze the architectural impact of a symbol

Fields



Status

Returns current workspace context and available commands



Fetch

Extract raw code for a specific symbol using AST parsing

Fields

path: String
symbol: String


Blast

Check the blast radius (dependencies) of a symbol

Fields

path: String
symbol: String


Search

Semantic keyword search over the codebase index

Fields

query: String


Mcp

Start the MCP server